==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/argumentsink.h <==
//$Id: argumentsink.h,v 1.1 2001/04/17 17:23:28 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 *
 * This portion of the code is written by Martin Schulze <MHL.Schulze@t-online.de>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_ARGUMENT_SINK_H
#define GUIKACHU_ARGUMENT_SINK_H

namespace SigC
{

    template <class R, class C1>
    struct AdaptorHideSlot1_1: public AdaptorSlot_
    {
#ifdef SIGC_CXX_PARTIAL_SPEC
	typedef R RType;
#else
	typedef typename Trait<R>::type RType;
#endif
	typedef Slot1<R,C1> SlotType;
	typedef Slot0<R> InSlotType;
	
	typedef CallDataObj2<typename SlotType::Func,AdaptorNode> CallData;
	
	static RType callback (void* d, C1 c1)
	    {
		CallData* data = (CallData*)d;
		AdaptorNode* node = data->obj;
		return ((typename InSlotType::Callback&)(node->data_))();
	    };
	
	static SlotData* create (SlotData *s)
	    {
		SlotData* tmp = (SlotData*)s;
		AdaptorNode* node = new AdaptorNode();
		copy_callback (tmp, node);
		CallData& data = reinterpret_cast<CallData&> (tmp->data_);
		data.callback = &callback;
		data.obj = node;
		return tmp;
	    }
    };
    
    template <class R, class C1>
    inline Slot1<R, C1> hide (const SigC::Slot0<R> &s)
    {
	return AdaptorHideSlot1_1<R,C1>::create(s.data());
    }
}

#endif /* !GUIKACHU_ARGUMENT_SINK_H */

==> guikachu-1.1.1.tar.gz: guikachu-1.1.1/src/argumentsink.h <==
//$Id: argumentsink.h,v 1.2 2001/12/20 23:42:48 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 *
 * This portion of the code is written by Martin Schulze <MHL.Schulze@t-online.de>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_ARGUMENT_SINK_H
#define GUIKACHU_ARGUMENT_SINK_H

namespace SigC
{

    template <class R, class C1>
    struct AdaptorHideSlot1_0: public AdaptorSlot_
    {
#ifdef SIGC_CXX_PARTIAL_SPEC
	typedef R RType;
#else
	typedef typename Trait<R>::type RType;
#endif
	typedef Slot1<R,C1> SlotType;
	typedef Slot0<R> InSlotType;
	
	typedef CallDataObj2<typename SlotType::Func,AdaptorNode> CallData;
	
	static RType callback (void* d, C1 c1)
	    {
		CallData* data = (CallData*)d;
		AdaptorNode* node = data->obj;
		return ((typename InSlotType::Callback&)(node->data_))();
	    };
	
	static SlotData* create (SlotData *s)
	    {
		SlotData* tmp = (SlotData*)s;
		AdaptorNode* node = new AdaptorNode();
		copy_callback (tmp, node);
		CallData& data = reinterpret_cast<CallData&> (tmp->data_);
		data.callback = &callback;
		data.obj = node;
		return tmp;
	    }
    };

    template <class R, class C1, class C2, class C3, class C4>
    struct AdaptorHideSlot4_0: public AdaptorSlot_
    {
#ifdef SIGC_CXX_PARTIAL_SPEC
	typedef R RType;
#else
	typedef typename Trait<R>::type RType;
#endif
	typedef Slot4<R,C1,C2,C3,C4> SlotType;
	typedef Slot0<R> InSlotType;
	
	typedef CallDataObj2<typename SlotType::Func,AdaptorNode> CallData;
	
	static RType callback (void* d, C1 c1, C2 c2, C3 c3, C4 c4)
	    {
		CallData* data = (CallData*)d;
		AdaptorNode* node = data->obj;
		return ((typename InSlotType::Callback&)(node->data_))();
	    };
	
	static SlotData* create (SlotData *s)
	    {
		SlotData* tmp = (SlotData*)s;
		AdaptorNode* node = new AdaptorNode();
		copy_callback (tmp, node);
		CallData& data = reinterpret_cast<CallData&> (tmp->data_);
		data.callback = &callback;
		data.obj = node;
		return tmp;
	    }
    };
    
    template <class R, class C1>
    inline Slot1<R, C1> hide (const SigC::Slot0<R> &s)
    {
	return AdaptorHideSlot1_0<R,C1>::create(s.data());
    }

    template <class R, class C1, class C2, class C3, class C4>
    inline Slot4<R, C1, C2, C3, C4> hide (const SigC::Slot0<R> &s)
    {
	return AdaptorHideSlot4_0<R,C1,C2,C3,C4>::create(s.data());
    }
}

#endif /* !GUIKACHU_ARGUMENT_SINK_H */
